/**
 *******************************************************************************
 * @file    systick.h
 *
 * @brief   System initialization header file.
 *
 * @author  LPX
 *
 * @version V1.0.0
 *
 * @date    2023-11-13
 *
 *******************************************************************************/
#ifndef _SYSTICK_H_
#define _SYSTICK_H_

#ifdef __cplusplus
extern "C" {
#endif

/* Includes */
#include "dpm32m0xx_rcc.h"
#include "dpm32m0xx_flash.h"


/* System delay function. */
void IncTick(void);
uint32_t GetTick(void);
void DelayMs(uint32_t Delay);

/* System initialization function. */
void SystemClockInit(void);
void SystickInit(void);


#ifdef __cplusplus
}
#endif

#endif /* _SYS_H_ */
